@@ -5,6 +5,7 @@ from five.customerize.zpt import TTWViewTemplate
 from five.customerize.utils import findViewletTemplate
 from zope.publisher.interfaces.browser import IBrowserRequest
 from zope.component import getGlobalSiteManager, getUtility
+from zope.viewlet.interfaces import IViewlet
 from plone.portlets.interfaces import IPortletRenderer
 from os.path import basename
 
@@ -37,6 +38,7 @@ def templateViewRegistrations():
         if name.startswith('SimpleViewClass') or \
                 name.startswith('SimpleViewletClass') or \
                 name.endswith('Viewlet') or \
+                IViewlet.implementedBy(factory) or \
                 IPortletRenderer.implementedBy(factory):
             attr, pt = findViewletTemplate(factory)
             if pt:
@@ -58,7 +60,8 @@ def templateViewRegistrationInfos(regs):
             if attr is None:        # skip, if the factory has no template...
                 continue
             zptfile = mangleAbsoluteFilename(pt.filename)
-            zcmlfile = mangleAbsoluteFilename(reg.info.file)
+            zcmlfile = getattr(reg.info, 'file', None)
+            zcmlfile = zcmlfile and mangleAbsoluteFilename(zcmlfile)
             name = reg.name or basename(zptfile)
             customized = None
         yield {
@@ -66,7 +69,7 @@ def templateViewRegistrationInfos(regs):
             'for': interfaceName(reg.required[0]),
             'type': interfaceName(reg.required[-1]),
             'zptfile': zptfile,
-            'zcmlfile': zcmlfile,
+            'zcmlfile': zcmlfile or 'n.a.',
             'customized': customized,
         }
 
